@@ -35,15 +35,13 @@
 
 class QDomDocument;
 class QDomNode;
-template <class T> class QList;
-template <class K, class T> class QHash;
+template<class T> class QList;
+template<class K, class T> class QHash;
 class QString;
 
 class KJob;
 
-namespace Akregator
-{
-
+namespace Akregator {
 class Article;
 class Feed;
 class FeedList;
@@ -51,8 +49,7 @@ class FetchQueue;
 class Folder;
 class TreeNode;
 
-namespace Backend
-{
+namespace Backend {
 class Storage;
 }
 
@@ -62,12 +59,12 @@ public:
     explicit FeedListManagementImpl(const QSharedPointer<FeedList> &list = QSharedPointer<FeedList>());
     void setFeedList(const QSharedPointer<FeedList> &list);
 
-    QStringList categories() const Q_DECL_OVERRIDE;
-    QStringList feeds(const QString &catId) const Q_DECL_OVERRIDE;
-    void addFeed(const QString &url, const QString &catId) Q_DECL_OVERRIDE;
-    void removeFeed(const QString &url, const QString &catId) Q_DECL_OVERRIDE;
-    QString addCategory(const QString &name, const QString &parentId) const Q_DECL_OVERRIDE;
-    QString getCategoryName(const QString &catId) const Q_DECL_OVERRIDE;
+    QStringList categories() const override;
+    QStringList feeds(const QString &catId) const override;
+    void addFeed(const QString &url, const QString &catId) override;
+    void removeFeed(const QString &url, const QString &catId) override;
+    QString addCategory(const QString &name, const QString &parentId) const override;
+    QString getCategoryName(const QString &catId) const override;
 
 private:
     QSharedPointer<FeedList> m_feedList;
@@ -197,7 +194,6 @@ private:
     class Private;
     Private *const d;
 };
-
 } // namespace Akregator
 
 #endif // AKREGATOR_FEEDLIST_H
